@@ -178,7 +178,7 @@ public:
      *
      * @return  a set of error codes
      */
-    Q_REQUIRED_RESULT MetaDataErrors metaDataErrors() const;
+    [[nodiscard]] MetaDataErrors metaDataErrors() const;
     /**
      * The maximum accepted metadata size.
      *
@@ -188,7 +188,7 @@ public:
      *
      * @return  the maximum value size in octets, or -1 if the limit is unknown
      */
-    Q_REQUIRED_RESULT qint64 maxAcceptedSize();
+    [[nodiscard]] qint64 maxAcceptedSize();
 
 protected:
     void doStart() override;
@@ -198,4 +198,3 @@ protected:
 }
 
 Q_DECLARE_OPERATORS_FOR_FLAGS(KIMAP::SetMetaDataJob::MetaDataErrors)
-
